Track RulesManagerService frameworks/base changes
am: da40e61fe0

Change-Id: Ifbbf95e5966aa61336e60955e563b8967973f31b
diff --git a/src/main/com/android/timezone/updater/RulesCheckReceiver.java b/src/main/com/android/timezone/updater/RulesCheckReceiver.java
index 003b2e4..f40fb00 100644
--- a/src/main/com/android/timezone/updater/RulesCheckReceiver.java
+++ b/src/main/com/android/timezone/updater/RulesCheckReceiver.java
@@ -163,7 +163,7 @@
         // is installed then the system will treat this as a no-op, and if something is installed
         // this will stage an uninstall.
         // We could install the distro from an app contained in the system image but we assume it's
         // going to contain the same time zone data as in /system and would be a no op.
 
         ApplicationInfo applicationInfo = providerInfo.applicationInfo;
         // isPrivilegedApp() => initial install directory for app /system/priv-app (required)
@@ -216,8 +216,8 @@
         // Decide whether to proceed with the install.
         RulesState rulesState = mRulesManager.getRulesState();
         if (!rulesState.isDistroFormatVersionSupported(distroFormatVersion)
-            || rulesState.isSystemVersionNewerThan(distroRulesVersion)) {
-            Log.d(TAG, "Candidate distro is not supported or is not better than system version.");
+            || rulesState.isBaseVersionNewerThan(distroRulesVersion)) {
+            Log.d(TAG, "Candidate distro is not supported or is not better than base version.");
             // Nothing to do.
             handleCheckComplete(checkToken, true /* success */);
             return;
@@ -163,7 +163,7 @@
         // this will stage an uninstall.
         // We could install the distro from an app contained in the system image but we assume it's
-        // going to contain the same time zone data as in /system and would be a no op.
+        // going to contain the same time zone data as the base version and would be a no op.
 
         ApplicationInfo applicationInfo = providerInfo.applicationInfo;